@@ -1,5 +1,5 @@
-#  tests for h5py-3.4.0-nompi_py39hd4deaf1_101 (this is a generated file);
-print('===== testing package: h5py-3.4.0-nompi_py39hd4deaf1_101 =====');
+#  tests for h5py-3.6.0-nompi_py39hd4deaf1_100 (this is a generated file);
+print('===== testing package: h5py-3.6.0-nompi_py39hd4deaf1_100 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import os
@@ -36,10 +36,13 @@ have_mpi = h5py.get_config().mpi
 assert have_mpi == should_have_mpi, "Expected mpi=%r, got %r" % (should_have_mpi, have_mpi)
 
 from sys import exit
-exit(h5py.run_tests())
+if have_mpi:
+    exit(h5py.run_tests("--with-mpi"))
+else:
+    exit(h5py.run_tests())
 #  --- run_test.py (end) ---
 
-print('===== h5py-3.4.0-nompi_py39hd4deaf1_101 OK =====');
+print('===== h5py-3.6.0-nompi_py39hd4deaf1_100 OK =====');
 print("import: 'h5py'")
 import h5py
 
